pub enum Action {
Insert {
pos: Option<u32>,
text: Option<String>,
},
Erase {
pos: Option<u32>,
num: Num,
},
Wait {
time: u32,
},
}Expand description
Choice between the three possible actions.
Variants
Insert
Supports the transmission of text, including key presses, and text block inserts.
Fields
Erase
Supports the behavior of backspace key presses. Text is removed towards beginning of the message. This element is also used for all delete operations, including the backspace key, the delete key, and text block deletes.
Fields
Wait
Allow for the transmission of intervals, between real-time text actions, to recreate the pauses between key presses.